==> code_saturne-8.1.1-3-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__file_8h.js <==
var cs__file_8h =
[
    [ "cs_file_off_t", "cs__file_8h.html#a53e7d7ae9fc77f3b619aea85ff0b34a8", null ],
    [ "cs_file_serializer_t", "cs__file_8h.html#a372dd3bbe75def7878d4ef6807a6cc5c", null ],
    [ "cs_file_t", "cs__file_8h.html#a781a9a0648504707114513517da1ce00", null ],
    [ "cs_file_access_t", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aef", [
      [ "CS_FILE_DEFAULT", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefaecbc4aa0d402208592005941b0641962", null ],
      [ "CS_FILE_STDIO_SERIAL", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefaa36cefaa3b79bef5c956dcdfef4f7943", null ],
      [ "CS_FILE_STDIO_PARALLEL", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefab1ff8b4cf86608bbcec59fc10bd0118c", null ],
      [ "CS_FILE_MPI_INDEPENDENT", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa153bd3db30344fe4d4fb2ef1f9c2cf57", null ],
      [ "CS_FILE_MPI_NON_COLLECTIVE", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa36d26061d5b2e5a5958ab1321f4594f9", null ],
      [ "CS_FILE_MPI_COLLECTIVE", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa2ef32e0f6225eeaee7dd38661387c87f", null ]
    ] ],
    [ "cs_file_mode_t", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0", [
      [ "CS_FILE_MODE_READ", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0ae6233f7ac4791779bfefba0f2c3ee9ab", null ],
      [ "CS_FILE_MODE_WRITE", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0a485f74b1deaa2e66703e8ebe79592e0d", null ],
      [ "CS_FILE_MODE_APPEND", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0a1460ac86aa43b0778cf39c7758cf6fcc", null ]
    ] ],
    [ "cs_file_mpi_positioning_t", "cs__file_8h.html#aec41af34ef1f3d18a4557c081cb1b97e", [
      [ "CS_FILE_MPI_EXPLICIT_OFFSETS", "cs__file_8h.html#aec41af34ef1f3d18a4557c081cb1b97eac7a2ab87b24ae4a2cdd588dd2d93e50b", null ],
      [ "CS_FILE_MPI_INDIVIDUAL_POINTERS", "cs__file_8h.html#aec41af34ef1f3d18a4557c081cb1b97ea79182568fad35d95654436471d5132bf", null ]
    ] ],
    [ "cs_file_seek_t", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132f", [
      [ "CS_FILE_SEEK_SET", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132fa357dc09ebe93e0f1276f08559ed130dc", null ],
      [ "CS_FILE_SEEK_CUR", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132fad1eb0721c77f6dca54dfb8f8c43793e1", null ],
      [ "CS_FILE_SEEK_END", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132fa9cb5f74b40e2e6701d7c97a6bb8bfa24", null ]
    ] ],
    [ "cs_file_block_comm", "cs__file_8h.html#abed647c6e4dc72923cde0a5a7c8ae8af", null ],
    [ "cs_file_defaults_info", "cs__file_8h.html#ab289f18d10bd270b620bf72d696e9d84", null ],
    [ "cs_file_dump", "cs__file_8h.html#a02f630c1509e730a44ff44f3032c2d65", null ],
    [ "cs_file_endswith", "cs__file_8h.html#a99fb73a147aaea2073c8f6b7bcaa31c6", null ],
    [ "cs_file_free", "cs__file_8h.html#ab7d1ec5c6b8e25b43e95da6fa0a043cc", null ],
    [ "cs_file_free_defaults", "cs__file_8h.html#a719edd7ea03688794b2600d9cd09209d", null ],
    [ "cs_file_get_default_access", "cs__file_8h.html#a242c021036e5a39166dd74d4ea7c48df", null ],
    [ "cs_file_get_default_comm", "cs__file_8h.html#a56f9a6900a210215bde3193bb883b91c", null ],
    [ "cs_file_get_mpi_io_positioning", "cs__file_8h.html#ad918616b700b849f80b44065367849db", null ],
    [ "cs_file_get_name", "cs__file_8h.html#aae4b05b9045a8636d8d6c3bfb0b268fc", null ],
    [ "cs_file_get_swap_endian", "cs__file_8h.html#a20f8fdee34caca95ceb336d260a5bbf1", null ],
    [ "cs_file_gets", "cs__file_8h.html#a0954e061a8aae4b16714b9ff1317ea6e", null ],
    [ "cs_file_gets_try", "cs__file_8h.html#a955c9bf7a18f835f07213c41987e46eb", null ],
    [ "cs_file_isdir", "cs__file_8h.html#a421ede780be23a77c49e29a0ce2f7cda", null ],
    [ "cs_file_isreg", "cs__file_8h.html#a9bd1b14662a466f01f128bda9324abb5", null ],
    [ "cs_file_listdir", "cs__file_8h.html#a76e8f2fd41c75008bba3e05a506a9acc", null ],
    [ "cs_file_mkdir_default", "cs__file_8h.html#ac37f904e767b1542c1dc3c4925dd59a1", null ],
    [ "cs_file_open", "cs__file_8h.html#a0bc331afd18841f52eede5dd62c13f8d", null ],
    [ "cs_file_open_default", "cs__file_8h.html#adf86aff1ceceeb79da390bf8c6c65d6f", null ],
    [ "cs_file_open_serial", "cs__file_8h.html#a983718a7ab45450a5005818bdaebf4d2", null ],
    [ "cs_file_read_block", "cs__file_8h.html#a6ff895aef5067e8009216f889744135b", null ],
    [ "cs_file_read_global", "cs__file_8h.html#ab58ceb9c4a81bd5e0cb215953f0667a4", null ],
    [ "cs_file_remove", "cs__file_8h.html#a88dcca1085ff0020740d3123f2e5dd83", null ],
    [ "cs_file_seek", "cs__file_8h.html#a980eb0f11f047380528ec909bce12767", null ],
    [ "cs_file_serializer_advance", "cs__file_8h.html#ae9728f616664c0ad48f7893981f1592e", null ],
    [ "cs_file_serializer_create", "cs__file_8h.html#a182792b9965647ecbfe29ec879ce9da7", null ],
    [ "cs_file_serializer_destroy", "cs__file_8h.html#a2962240c0923fd218b7af09488ace0ae", null ],
    [ "cs_file_set_big_endian", "cs__file_8h.html#a7520981e6d52a7833bf994a5ec1a53be", null ],
    [ "cs_file_set_default_access", "cs__file_8h.html#ac221df4fa21b00eb5e0d3eafdeb79e64", null ],
    [ "cs_file_set_default_comm", "cs__file_8h.html#a2fa7fb1549c085752e8cff0ab68f7b26", null ],
    [ "cs_file_set_mpi_io_positioning", "cs__file_8h.html#aa96ac8afdf5dc4b98f1adce38a232c78", null ],
    [ "cs_file_set_swap_endian", "cs__file_8h.html#af90f4fd7c461698db3f2e456d231126c", null ],
    [ "cs_file_size", "cs__file_8h.html#a8479a6c2bae7de70b8038a10fdd91601", null ],
    [ "cs_file_tell", "cs__file_8h.html#a06581b688e89ad13b429dfcd5c04d5fc", null ],
    [ "cs_file_write_block", "cs__file_8h.html#ad84777d73bc540ee24456ed2754e5cd7", null ],
    [ "cs_file_write_block_buffer", "cs__file_8h.html#a8002b1374b8d1f9252c53194f8b12f97", null ],
    [ "cs_file_write_global", "cs__file_8h.html#a5ba6b189fa030f5aa97349dd6177bd09", null ],
    [ "cs_file_access_name", "cs__file_8h.html#ad88fb4f6654263dcee53194b5e75d287", null ],
    [ "cs_file_mpi_positioning_name", "cs__file_8h.html#a254849619da9782ef54c9d6c18cd2cbf", null ]
];

==> code_saturne-9.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/code_saturne/doxygen/src/cs__file_8h.js <==
var cs__file_8h =
[
    [ "cs_file_off_t", "cs__file_8h.html#a53e7d7ae9fc77f3b619aea85ff0b34a8", null ],
    [ "cs_file_t", "cs__file_8h.html#a781a9a0648504707114513517da1ce00", null ],
    [ "cs_file_access_t", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aef", [
      [ "CS_FILE_DEFAULT", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefac6693078333510674abaf553a8d15ef0", null ],
      [ "CS_FILE_STDIO_SERIAL", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefaa36cefaa3b79bef5c956dcdfef4f7943", null ],
      [ "CS_FILE_STDIO_PARALLEL", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefab1ff8b4cf86608bbcec59fc10bd0118c", null ],
      [ "CS_FILE_MPI_INDEPENDENT", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa153bd3db30344fe4d4fb2ef1f9c2cf57", null ],
      [ "CS_FILE_MPI_NON_COLLECTIVE", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa36d26061d5b2e5a5958ab1321f4594f9", null ],
      [ "CS_FILE_MPI_COLLECTIVE", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa2ef32e0f6225eeaee7dd38661387c87f", null ],
      [ "CS_FILE_IN_MEMORY_SERIAL", "cs__file_8h.html#a6dec92e98bc6cc54747d2a45ae9d2aefa22e8b5da71bc25dbcba29496259e93c0", null ]
    ] ],
    [ "cs_file_mode_t", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0", [
      [ "CS_FILE_MODE_READ", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0ae6233f7ac4791779bfefba0f2c3ee9ab", null ],
      [ "CS_FILE_MODE_WRITE", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0a485f74b1deaa2e66703e8ebe79592e0d", null ],
      [ "CS_FILE_MODE_APPEND", "cs__file_8h.html#ab2c85f2d08d550fb94868c7ce5fa2df0a1460ac86aa43b0778cf39c7758cf6fcc", null ]
    ] ],
    [ "cs_file_mpi_positioning_t", "cs__file_8h.html#aec41af34ef1f3d18a4557c081cb1b97e", [
      [ "CS_FILE_MPI_EXPLICIT_OFFSETS", "cs__file_8h.html#aec41af34ef1f3d18a4557c081cb1b97eac7a2ab87b24ae4a2cdd588dd2d93e50b", null ],
      [ "CS_FILE_MPI_INDIVIDUAL_POINTERS", "cs__file_8h.html#aec41af34ef1f3d18a4557c081cb1b97ea79182568fad35d95654436471d5132bf", null ]
    ] ],
    [ "cs_file_seek_t", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132f", [
      [ "CS_FILE_SEEK_SET", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132fa357dc09ebe93e0f1276f08559ed130dc", null ],
      [ "CS_FILE_SEEK_CUR", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132fad1eb0721c77f6dca54dfb8f8c43793e1", null ],
      [ "CS_FILE_SEEK_END", "cs__file_8h.html#ac485f7134b24617cd39b9f58309e132fa9cb5f74b40e2e6701d7c97a6bb8bfa24", null ]
    ] ],
    [ "cs_file_defaults_info", "cs__file_8h.html#ab289f18d10bd270b620bf72d696e9d84", null ],
    [ "cs_file_dump", "cs__file_8h.html#a02f630c1509e730a44ff44f3032c2d65", null ],
    [ "cs_file_endswith", "cs__file_8h.html#a99fb73a147aaea2073c8f6b7bcaa31c6", null ],
    [ "cs_file_free", "cs__file_8h.html#a5c16028868f938b96c184d6d44096d40", null ],
    [ "cs_file_free_defaults", "cs__file_8h.html#a719edd7ea03688794b2600d9cd09209d", null ],
    [ "cs_file_get_default_access", "cs__file_8h.html#af1b2d9738ee0ea2be059596121f640ae", null ],
    [ "cs_file_get_mpi_io_positioning", "cs__file_8h.html#ad918616b700b849f80b44065367849db", null ],
    [ "cs_file_get_name", "cs__file_8h.html#a3015f05f4d9082832ff9fea56f54cfcf", null ],
    [ "cs_file_get_swap_endian", "cs__file_8h.html#a20f8fdee34caca95ceb336d260a5bbf1", null ],
    [ "cs_file_gets", "cs__file_8h.html#ac33a6fb4e5d43355185e659f4b7bddac", null ],
    [ "cs_file_gets_try", "cs__file_8h.html#a6a1d17e0e3453582f643fcea9ad330b7", null ],
    [ "cs_file_in_memory_get_data", "cs__file_8h.html#a42432c21ade307650d0f9ee4df1976a7", null ],
    [ "cs_file_in_memory_transfer_data", "cs__file_8h.html#aa821febac5fecddcdf2085ed49c28c9b", null ],
    [ "cs_file_isdir", "cs__file_8h.html#a421ede780be23a77c49e29a0ce2f7cda", null ],
    [ "cs_file_isreg", "cs__file_8h.html#a9bd1b14662a466f01f128bda9324abb5", null ],
    [ "cs_file_listdir", "cs__file_8h.html#ac147bc624a198c9e050f7fcf01bd9e93", null ],
    [ "cs_file_mkdir_default", "cs__file_8h.html#ac37f904e767b1542c1dc3c4925dd59a1", null ],
    [ "cs_file_open", "cs__file_8h.html#a46a9849fb3a1f79000d087e9d156185c", null ],
    [ "cs_file_open_default", "cs__file_8h.html#a5f472557e25eaa622e508c17e3a45eda", null ],
    [ "cs_file_open_serial", "cs__file_8h.html#ad50327b2c760b7647ed4244ab295c464", null ],
    [ "cs_file_read_block", "cs__file_8h.html#a6ff895aef5067e8009216f889744135b", null ],
    [ "cs_file_read_global", "cs__file_8h.html#ab58ceb9c4a81bd5e0cb215953f0667a4", null ],
    [ "cs_file_remove", "cs__file_8h.html#a88dcca1085ff0020740d3123f2e5dd83", null ],
    [ "cs_file_seek", "cs__file_8h.html#a980eb0f11f047380528ec909bce12767", null ],
    [ "cs_file_set_allow_read_global_eof", "cs__file_8h.html#ae2b745e51be05664c3142121d571df40", null ],
    [ "cs_file_set_big_endian", "cs__file_8h.html#a7520981e6d52a7833bf994a5ec1a53be", null ],
    [ "cs_file_set_default_access", "cs__file_8h.html#a7385203f3f62c2ef6b03698daa55e575", null ],
    [ "cs_file_set_mpi_io_positioning", "cs__file_8h.html#aa96ac8afdf5dc4b98f1adce38a232c78", null ],
    [ "cs_file_set_swap_endian", "cs__file_8h.html#af90f4fd7c461698db3f2e456d231126c", null ],
    [ "cs_file_size", "cs__file_8h.html#a8479a6c2bae7de70b8038a10fdd91601", null ],
    [ "cs_file_tell", "cs__file_8h.html#a06581b688e89ad13b429dfcd5c04d5fc", null ],
    [ "cs_file_write_block", "cs__file_8h.html#ad84777d73bc540ee24456ed2754e5cd7", null ],
    [ "cs_file_write_block_buffer", "cs__file_8h.html#a8002b1374b8d1f9252c53194f8b12f97", null ],
    [ "cs_file_write_global", "cs__file_8h.html#a5ba6b189fa030f5aa97349dd6177bd09", null ],
    [ "cs_file_access_name", "cs__file_8h.html#ad88fb4f6654263dcee53194b5e75d287", null ],
    [ "cs_file_mpi_positioning_name", "cs__file_8h.html#a254849619da9782ef54c9d6c18cd2cbf", null ]
];
